<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca_ES">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Hi ha vida fora del navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versió %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Llicenciat a: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 és programari lliure, però el seu desenvolupament pren un temps preciós.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Siusplau &lt;a href=&apos;%1&apos;&gt;dóna&lt;/a&gt; per ajudar al desenvolupament continuat del %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduïu el %1 al vostre idioma natal utilitzant %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icona dissenyada per %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Alliberat sota la &lt;a href=&apos;%1&apos;&gt;Llicència Pública General de GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tanca</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Entra els detalls de la teva llicència</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Codi:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Si us plau, llicencia el %1</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Comprant la versió completa, també donarà suport al dur treball que he posat en la creació del %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Utilitza la demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Entra la lliçència </translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Comprar llicència</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Descarrega</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Per %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Tots els vídeos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vídeos no vists</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Últim actualitzat</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Últim afegit</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Últim vist</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Més vistos</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordena per</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Marca-ho tot vist</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Mostra actualitzats</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>No teniu subscripcions. Feu servir el símbol de l&apos;estrella per subscríure-us als canals.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Tots els vídeos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vídeos no vistos</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>No hi han subscripcions actualitzades.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 visualitzacions</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/s</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segons</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuts</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restant</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 descarregat en %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Descàrrega completada</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Canvia la ubicació...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Escull la ubicació de les baixades</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Ubicació de baixades canviada.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Les baixades actuals encara aniran a la ubicació prèvia.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Baixant a: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>El fitxer executable ha estat manipulat, potser per un virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 no funcionarà. Proveu tornar a instal·lar.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Reinstal·la</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Posa en pausa</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reprodueix/posa en pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Atura en acabar la peça actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Peça següent</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Peça prèvia</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Augmenta el volum</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Disminuex el volum</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silencia</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Cerca endavant</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Cerca enrere</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Troba vídeos i canals per paraula clau</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Explora</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Explora vídeos per categoria</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Subscripcions</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Subscripcions de canal</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Poseu-vos còmodes</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Finestra</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimitza</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Atura</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Atura la reproducció i torna a la vista de búsqueda</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>P&amp;revi</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Torna a la pista anterior</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Salta</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Salta al vídeo següent</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reprodueix</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continua la reproducció</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pantalla &amp;completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Passa a pantalla completa</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Mode compacte</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Amaga la llista de reproducció i la barra d&apos;eines</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Obre la pàgina de &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ves a la pàgina del vídeo del YouTube i pausa la reproducció</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Copia l&apos;&amp;enllaç de YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copia l&apos;enllaç del vídeo actual del YouTube al porta-retalls</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Copia el &amp;URL del flux de vídeo</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copia el URL del flux de vídeo actual al porta-retalls</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Troba &amp;parts de vídeo</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Troba altres parts del vídeo, amb sort en l&apos;ordre correcte</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Elimina els vídeos seleccionats de la llista de reproducció</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mou &amp;amunt</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mou amunt els vídeos seleccionats en la llista de reproducció</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mou a&amp;vall</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mou avall els vídeos seleccionats en la llista de reproducció</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Neteja les búsquedes recents</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Neteja l&apos;historial de búsquedes. No es pot desfer.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Adéu</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Pàgina &amp;web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 a la xarxa</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Fer una &amp;donació</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Siusplau ajuda al desenvolupament continuat del %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info sobre %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silencia el volum</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Reprodueix vídeos &amp;manualment</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Comença a reproduir vídeos manualment</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Baixades</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Mostra detalls de les descàrregues de vídeo</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Baixa</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Baixa el vídeo actual</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Subscriu al canal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Comparteix el vídeo actual fent servir %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Email</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Correu electrònic</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tanca</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>Manté a &amp;sobre</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Atura després d&apos;aquest vídeo</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Informa d&apos;un problema...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Afina la Cerca...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Més...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Vídeos &amp;Relacionats</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Visualitza vídeos relacionats amb l&apos;actual</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Obre al &amp;Navegador...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Commuta la &amp;barra de menús</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>T&apos;&amp;Agrada %1? Puntua&apos;l!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Compra %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicació</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Reproducció</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Llista de reproducció</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Vídeo</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Compartir</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vista</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Premeu %1 per pujar el volum, %2 per baixar-lo</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Esculliu la ubicació del vostre contingut</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Obrint %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Vol abandonar el %1 amb una baixada en curs?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Si tanca el %1 ara, aquesta baixada es cancel·larà.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Tanca i cancel·la la baixada</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Espera a acabar la baixada</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausa la reproducció</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Carregant...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Abandona la Pantalla &amp;Completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Temps restant: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volum al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>El volum està silenciat</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>El volum no està silenciat</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Resolució màxima de vídeo fixada a %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>La vostra privacitat ara és segura</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Baixades completes</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Encara podeu accedir a la barra de menús prement la tecla ALT</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Ja podeu enganxar l&apos;enllaç de YouTube en una altra aplicació</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Ja pot enganxar el URL del flux de vídeo en una altra aplicació</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>L&apos;enllaç només serà vàlid durant un temps limitat.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Baixant %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>de</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>part</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episodi</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Enviat des de %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Cancel·la la subscripció a %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Subscriu-me a %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>channel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Una nova versió de %1 està disponible</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 estan disponibles. Tu tens %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>T&apos;agradaria descarregar-ho ara?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Omet aquesta versió</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Recorda-m&apos;ho després</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instal·la Actualització</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Enganxar</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparant</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Fallit</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completat</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Aturat</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Atura la baixada</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Mostra en %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Obre el directori superior</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Recomença la baixada</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Mostra %1 Més</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Cap vídeo</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Cap més vídeo</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Ordena per</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Rellevància</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Nombre de vistes</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Qualificació</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Qualsevol data</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dies</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dies</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duració</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tot</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Curt</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mig</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Llarg</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Menys de 4 minuts</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Entre 4 i 20 minuts</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Més de 20 minuts</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualitat</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4K</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HDR</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Benvinguts al &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>per comencar a veure vídeos.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>una paraula</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Introdueix</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Búsquedes recents</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Canals recents</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Aconsegueix la versió completa</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Enrere</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Avança a %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Retrocedeix a %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Afina la Cerca</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Volieu dir: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Canvia la ubicació...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Més popular</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>News</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gaming</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Descarregant actualitzacions...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Descarregant %1...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Descarregant actualitzacions...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>No es pot obtenir flux de vídeo per %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algèria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Austràlia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Bèlgica</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canadà</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Xile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colòmbia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>República Txeca</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egipte</translation>
    </message>
    <message>
        <source>France</source>
        <translation>França</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Alemanya</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grècia</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hongria</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Índia</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonèsia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Itàlia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japó</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordània</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malàisia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mèxic</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marroc</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Holanda</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nova Zelanda</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigèria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Perú</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipines</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polònia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rússia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Aràbia Saudita</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Sud-àfrica</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Corea del Sud</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Espanya</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Suècia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunísia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turquia</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Emirats Àrabs Units</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Regne Unit</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Global</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>No es pot obtenir flux de vídeo per %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Una nova versió de %1 està disponible</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 està disponible. Tu tens %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>T&apos;agradaria descarregar-ho ara?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Recorda-m&apos;ho després</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>